@@ -1,12 +1,14 @@
 from datetime import datetime
 import logging
 import threading
-from time import sleep, time
-import Pyro4
+from time import time
 import sys
+
 from pyage.core import inject
+
 from pyage.core.workplace import Workplace
 
+
 logger = logging.getLogger(__name__)
 
 if __name__ == '__main__':
@@ -22,18 +24,12 @@ if __name__ == '__main__':
         thread = threading.Thread(target=workspace.daemon.requestLoop)
         thread.setDaemon(True)
         thread.start()
-    Pyro4.config.COMMTIMEOUT = 1
+        import Pyro4
+        Pyro4.config.COMMTIMEOUT = 1
     while not workspace.stopped:
         workspace.step()
-        try:
-            sleep(float(sys.argv[2]))
-        except IndexError:
-            pass
-    try:
-        time = time() - start_time
-        logger.debug("elapsed time: %s seconds", time)
-    except:
-        logger.exception("could not open url")
+    time = time() - start_time
+    logger.debug("elapsed time: %s seconds", time)
     if hasattr(workspace, "daemon"):
         workspace.daemon.close()
     workspace.unregister_agents()
